Class: WikiCloth::WikiCloth
- Inherits:
-
Object
- Object
- WikiCloth::WikiCloth
- Defined in:
- lib/wikicloth.rb
Instance Method Summary collapse
-
#initialize(opt = {}) ⇒ WikiCloth
constructor
A new instance of WikiCloth.
- #link_handler ⇒ Object
- #load(data, p = {}) ⇒ Object
- #method_missing(method, *args) ⇒ Object
- #options ⇒ Object
- #params ⇒ Object
- #render(opt = {}) ⇒ Object
- #sections ⇒ Object
- #to_html(opt = {}) ⇒ Object
Constructor Details
#initialize(opt = {}) ⇒ WikiCloth
Returns a new instance of WikiCloth.
22 23 24 25 26 27 28 29 |
# File 'lib/wikicloth.rb', line 22 def initialize(opt={}) self..merge!(opt) self.[:extensions] ||= [] self.[:link_handler] = opt[:link_handler] unless opt[:link_handler].nil? self.load(opt[:data],opt[:params]) unless opt[:data].nil? @current_line = 1 @current_row = 0 end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(method, *args) ⇒ Object
122 123 124 125 126 127 128 |
# File 'lib/wikicloth.rb', line 122 def method_missing(method, *args) if self.link_handler.respond_to?(method) self.link_handler.send(method, *args) else super(method, *args) end end |
Instance Method Details
#link_handler ⇒ Object
110 111 112 |
# File 'lib/wikicloth.rb', line 110 def link_handler self.[:link_handler] ||= WikiLinkHandler.new end |
#load(data, p = {}) ⇒ Object
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/wikicloth.rb', line 31 def load(data,p={}) depth = 1 count = 0 root = [self.sections] # parse wiki document into sections data.each_line do |line| if line =~ /^([=]{1,6})\s*(.*?)\s*(\1)/ root << root.last[-1].children if $1.length > depth root.pop if $1.length < depth depth = $1.length root.last << Section.new(line, get_id_for($2.gsub(/\s+/,'_'))) count += 1 else root.last[-1] << line end end # if we find template variables assume document is # a template self.sections.first.template = true if data =~ /\{\{\{\s*([A-Za-z0-9]+)\s*\}\}\}/ # If there are more than four sections enable automatic # table of contents self.sections.first.auto_toc = true unless count < 4 || data =~ /__(NO|)TOC__/ self.params = p end |
#options ⇒ Object
118 119 120 |
# File 'lib/wikicloth.rb', line 118 def @options ||= {} end |
#params ⇒ Object
114 115 116 |
# File 'lib/wikicloth.rb', line 114 def params @page_params ||= {} end |
#render(opt = {}) ⇒ Object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/wikicloth.rb', line 60 def render(opt={}) self. = { :noedit => false, :fast => true, :output => :html, :link_handler => self.link_handler, :params => self.params, :sections => self.sections }.merge(self.).merge(opt) self.[:link_handler].params = [:params] locale = self.[:locale] || I18n.locale I18n.with_locale(locale) do data = self.sections.collect { |s| s.render(self.) }.join data.gsub!(/<!--(.|\s)*?-->/,"") data << "\n" if data.last(1) != "\n" data << "garbage" buffer = WikiBuffer.new("",) begin if self.[:fast] until data.empty? case data when /\A\w+/ data = $' @current_row += $&.length buffer.add_word($&) when /\A[^\w]+(\w|)/m data = $' $&.each_char { |c| add_current_char(buffer,c) } end end else data.each_char { |c| add_current_char(buffer,c) } end rescue => err debug_tree = buffer.buffers.collect { |b| b.debug }.join("-->") puts I18n.t("unknown error on line", :line => @current_line, :row => @current_row, :tree => debug_tree) raise err end buffer.eof() buffer.send("to_#{self.[:output]}") end end |
#sections ⇒ Object
102 103 104 |
# File 'lib/wikicloth.rb', line 102 def sections @sections ||= [Section.new] end |
#to_html(opt = {}) ⇒ Object
106 107 108 |
# File 'lib/wikicloth.rb', line 106 def to_html(opt={}) self.render(opt.merge(:output => :html)) end |